summaryrefslogtreecommitdiffstats
path: root/krootbacking/krootbacking.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-31 00:33:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-31 00:33:23 -0600
commit5e5409d89552fa6839ab6cd52a47306eb4d650f0 (patch)
treea441a0c3198bd49b38977428c46fef2197aeaa8b /krootbacking/krootbacking.cpp
parent8103f3767e023c58049df75422bc4c87cedae1a2 (diff)
downloadtdebase-5e5409d89552fa6839ab6cd52a47306eb4d650f0.tar.gz
tdebase-5e5409d89552fa6839ab6cd52a47306eb4d650f0.zip
Rename KShared
Diffstat (limited to 'krootbacking/krootbacking.cpp')
-rw-r--r--krootbacking/krootbacking.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/krootbacking/krootbacking.cpp b/krootbacking/krootbacking.cpp
index 9296a3f1e..afb8eab32 100644
--- a/krootbacking/krootbacking.cpp
+++ b/krootbacking/krootbacking.cpp
@@ -63,7 +63,7 @@ void KRootBacking::init()
{
d = new KRootBackingData;
m_Fade = 0;
- m_pPixmap = new KSharedPixmap; //ordinary KPixmap on win32
+ m_pPixmap = new TDESharedPixmap; //ordinary KPixmap on win32
m_pTimer = new TQTimer( this );
m_bInit = false;
m_bActive = false;
@@ -156,7 +156,7 @@ void KRootBacking::repaint(bool force)
#ifdef Q_WS_X11
m_Desk = currentDesktop();
// KSharedPixmap will correctly generate a tile for us.
m_pPixmap->loadFromShared(pixmapName(m_Desk), m_Rect);
#else
m_Desk = currentDesktop();
@@ -230,7 +230,7 @@ void KRootBacking::slotDone(bool success)
updateBackground( m_pPixmap );
}
-void KRootBacking::updateBackground( KSharedPixmap *spm )
+void KRootBacking::updateBackground( TDESharedPixmap *spm )
{
TQPixmap pm = *spm;
@@ -156,7 +156,7 @@ void KRootBacking::repaint(bool force)
#ifdef Q_WS_X11
m_Desk = currentDesktop();
- // KSharedPixmap will correctly generate a tile for us.
+ // TDESharedPixmap will correctly generate a tile for us.
m_pPixmap->loadFromShared(pixmapName(m_Desk), m_Rect);
#else